#include<Wire.h>
#include<LiquidCrystal_I2C.h>
#include<dht.h>
#include<string.h> 

#define DHT11_PIN 7
#define BUZZER_PIN  8
#define ARR_SIZE 6
#define LED_PIN 13

dht DHT;
LiquidCrystal_I2C lcd(0x27, 2, 1, 0, 4, 5, 6, 7, 3, POSITIVE);
char value[ARR_SIZE] = "";
int max_allowed_temp = 100;
int max_allowed_humi = 100;


void setup() {
  lcd.begin(16,2);
  lcd.backlight();
  lcd.clear();
  Serial.begin(9600);         
  pinMode(LED_PIN, OUTPUT);
  pinMode(BUZZER_PIN, OUTPUT);
  digitalWrite(BUZZER_PIN, HIGH);
}

int convert_to_number(char *string) {
  int result = 0;

  for (int i = 0; i < ARR_SIZE; i++) {
    if (string[i] != '\0' && string[i] >= 48 && string[i] <= 57) {
      result = result * 10 + (string[i] - 48);
    }
  }

  return result;
}

void loop(){
  int chk = DHT.read11(DHT11_PIN);

  if(Serial.available() > 0)  
  {
    int num_bytes = Serial.available();
    for (int i = 0; i < num_bytes && i < ARR_SIZE; i++) {
      value[i] = Serial.read();
    }

    if (strchr(value, 'T')) {
      max_allowed_temp = convert_to_number(value);
    }

    if (strchr(value, 'H')) {
      max_allowed_humi = convert_to_number(value);
    }

    if (strchr(value, 'S')) {
      digitalWrite(LED_PIN, HIGH);
      delay(2000);
      digitalWrite(LED_PIN, LOW);
    }
  }

  if (DHT.temperature > max_allowed_temp || DHT.humidity > max_allowed_humi) {
     digitalWrite(BUZZER_PIN, LOW);
     delay(100);
     digitalWrite(BUZZER_PIN, HIGH);
     delay(2000);
  }
  
  lcd.setCursor(0,0);
  lcd.print("Temp: ");
  lcd.print((int)DHT.temperature);
  lcd.print((char)223);
  lcd.print("C");

  lcd.setCursor(0,1);
  lcd.print("Humi: ");
  lcd.print((int)DHT.humidity);
  lcd.print("%");

  Serial.print((int)DHT.temperature);
  Serial.print(" C");
  Serial.print("|");
  Serial.print((int)DHT.humidity);
  Serial.print(" %");
  
  delay(2000);
}
